# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asvprotobuf/nav.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from asvprotobuf import std_pb2 as asvprotobuf_dot_std__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='asvprotobuf/nav.proto',
  package='asvprotobuf.nav',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x15\x61svprotobuf/nav.proto\x12\x0f\x61svprotobuf.nav\x1a\x15\x61svprotobuf/std.proto\"\x8d\x01\n\x04Pose\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.asvprotobuf.std.Header\x12)\n\x08position\x18\x0f \x01(\x0b\x32\x17.asvprotobuf.std.Vector\x12\x31\n\x0borientation\x18\x10 \x01(\x0b\x32\x1c.asvprotobuf.std.Orientation\"\x88\x01\n\x05Twist\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.asvprotobuf.std.Header\x12\'\n\x06linear\x18\x0f \x01(\x0b\x32\x17.asvprotobuf.std.Vector\x12-\n\x07\x61ngular\x18\x10 \x01(\x0b\x32\x1c.asvprotobuf.std.Orientation\"\xb2\x01\n\x08Odometry\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.asvprotobuf.std.Header\x12#\n\x04pose\x18\x0f \x01(\x0b\x32\x15.asvprotobuf.nav.Pose\x12\x17\n\x0fpose_covariance\x18\x10 \x03(\x01\x12%\n\x05twist\x18\x11 \x01(\x0b\x32\x16.asvprotobuf.nav.Twist\x12\x18\n\x10twist_covariance\x18\x12 \x03(\x01\x62\x06proto3')
  ,
  dependencies=[asvprotobuf_dot_std__pb2.DESCRIPTOR,])




_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='asvprotobuf.nav.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='asvprotobuf.nav.Pose.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='asvprotobuf.nav.Pose.position', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='asvprotobuf.nav.Pose.orientation', index=2,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=207,
)


_TWIST = _descriptor.Descriptor(
  name='Twist',
  full_name='asvprotobuf.nav.Twist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='asvprotobuf.nav.Twist.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linear', full_name='asvprotobuf.nav.Twist.linear', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angular', full_name='asvprotobuf.nav.Twist.angular', index=2,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=346,
)


_ODOMETRY = _descriptor.Descriptor(
  name='Odometry',
  full_name='asvprotobuf.nav.Odometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='asvprotobuf.nav.Odometry.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pose', full_name='asvprotobuf.nav.Odometry.pose', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pose_covariance', full_name='asvprotobuf.nav.Odometry.pose_covariance', index=2,
      number=16, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twist', full_name='asvprotobuf.nav.Odometry.twist', index=3,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twist_covariance', full_name='asvprotobuf.nav.Odometry.twist_covariance', index=4,
      number=18, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=527,
)

_POSE.fields_by_name['header'].message_type = asvprotobuf_dot_std__pb2._HEADER
_POSE.fields_by_name['position'].message_type = asvprotobuf_dot_std__pb2._VECTOR
_POSE.fields_by_name['orientation'].message_type = asvprotobuf_dot_std__pb2._ORIENTATION
_TWIST.fields_by_name['header'].message_type = asvprotobuf_dot_std__pb2._HEADER
_TWIST.fields_by_name['linear'].message_type = asvprotobuf_dot_std__pb2._VECTOR
_TWIST.fields_by_name['angular'].message_type = asvprotobuf_dot_std__pb2._ORIENTATION
_ODOMETRY.fields_by_name['header'].message_type = asvprotobuf_dot_std__pb2._HEADER
_ODOMETRY.fields_by_name['pose'].message_type = _POSE
_ODOMETRY.fields_by_name['twist'].message_type = _TWIST
DESCRIPTOR.message_types_by_name['Pose'] = _POSE
DESCRIPTOR.message_types_by_name['Twist'] = _TWIST
DESCRIPTOR.message_types_by_name['Odometry'] = _ODOMETRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pose = _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), dict(
  DESCRIPTOR = _POSE,
  __module__ = 'asvprotobuf.nav_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.nav.Pose)
  ))
_sym_db.RegisterMessage(Pose)

Twist = _reflection.GeneratedProtocolMessageType('Twist', (_message.Message,), dict(
  DESCRIPTOR = _TWIST,
  __module__ = 'asvprotobuf.nav_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.nav.Twist)
  ))
_sym_db.RegisterMessage(Twist)

Odometry = _reflection.GeneratedProtocolMessageType('Odometry', (_message.Message,), dict(
  DESCRIPTOR = _ODOMETRY,
  __module__ = 'asvprotobuf.nav_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.nav.Odometry)
  ))
_sym_db.RegisterMessage(Odometry)


# @@protoc_insertion_point(module_scope)
